@@ -35,6 +35,14 @@ impl Location {
     pub fn is_azure(&self) -> bool {
         matches!(self, Location::Azure(_))
     }
+
+    pub fn region(&self) -> &str {
+        match self {
+            Location::Aws(region) => region.as_str(),
+            Location::Azure(region) => region.as_str(),
+            // Location::Gcp(region) => region.as_str(),
+        }
+    }
 }
 
 impl fmt::Display for Location {
